@@ -366,7 +366,7 @@ completionError = c' where
 
 spawnError :: (SpawnRecover a, Exception e) => Bool -> Bool -> Bool -> e -> IO a
 spawnError throw' die' warn' = f where
-    f   | throw'    = pure . throw
+    f   | throw'    = throw
         | die'      = die''
         | otherwise = g
     w e | warn' = warn $ show e
